@@ -13,9 +13,8 @@
  * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
  * more details.
  *
- * You should have received a copy of the GNU General Public License along with
- * this program; if not, write to the Free Software Foundation, Inc., 59 Temple
- * Place, Suite 330, Boston, MA  02111-1307  USA
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifndef __TERMINAL_SCREEN_H__
@@ -51,6 +50,12 @@ void         terminal_screen_set_size                     (TerminalScreen *scree
                                                            glong           width_chars,
                                                            glong           height_chars);
 
+void         terminal_screen_get_geometry                 (TerminalScreen *screen,
+                                                           glong          *char_width,
+                                                           glong          *char_height,
+                                                           gint           *xpad,
+                                                           gint           *ypad);
+
 void         terminal_screen_set_window_geometry_hints    (TerminalScreen *screen,
                                                            GtkWindow      *window);
 
